# Real-time visualizer for the IDUN Guardian 

## Overview
This repo allows to visualize real time data and predictions from the IDUN Guardian:
- **Filtered EEG Data**: Provides a clearer view of the EEG signal.
- **Frequency Bands**: Calculates FFT band z-scores for frequency-based analysis.
- **Jaw Clench and Eye Movement Detection**: Detects jaw clenches and horizontal eye movements (left or right) using two classifiers.
- **IMU Data**: Provides information about head movement (accelerometer, magnetometer and gyroscope)

These features are visualized in a dedicated display window, allowing for dynamic monitoring of EEG and IMU signals as well as classifier outputs.


## Prerequisites
- **Python 3.12**: Download [here](https://www.python.org/downloads/).
- **Pipenv**: Install via `pip`:
  ```bash
  > pip install pipenv
  ```
- **Realtime predictions**: your account should have realtime predictions activated. If this is not the case, please contact an IDUNian.

## Installation

1. **Create an empty Virtual Environment Folder**:
   ```bash
   > mkdir .venv
   ```

2. **Install Dependencies**:
   ```bash
   > pipenv install
   ```


## Setup

Open the scrip `demo.py` and configure your device address, API key, and any preferred recording parameters at the beginning of the script.


## Usage

1. **Activate the Environment and Run the Script**:
   ```bash
   > pipenv shell
   > python demo.py
   ```

2. **Deactivate the Environment**:
   To exit the pipenv environment:
   ```bash
   > exit
   ```


## Troubleshooting

- **Environment Issues**: If problems in the installation process occur, delete the `.venv` folder and `Pipfile.lock`, then repeat the steps 2 and 3 in [Installation](#installation) 
